GMMBoost: Likelihood-Based Boosting for Generalized Mixed Models
Description
This packages provides likelihood-based boosting approaches for Generalized mixed models
Arguments
Author
Andreas Groll
Details
Package:
GMMBoost
Type:
Package
Version:
1.1.3
Date:
2019-02-03
License:
GPL-2
LazyLoad:
yes
for loading a dataset type data(nameofdataset)
References
Special thanks goes to Manuel Eugster, Sebastian Kaiser, Fabian Scheipl and Felix Heinzl, who helped to create this package and whose insightful advices helped to improve the package.